pub struct BrokerId(/* private fields */);Implementations
Sourceimpl BrokerId
impl BrokerId
pub fn new(broker_id: (String, usize)) -> Self
Sourcepub async fn resolve<A: Actor>(
self,
cx: &Context<'_, A>,
) -> ActorHandle<LocalStateBrokerActor>
pub async fn resolve<A: Actor>( self, cx: &Context<'_, A>, ) -> ActorHandle<LocalStateBrokerActor>
Resolve the broker with exponential backoff retry. Broker creation can race with messages that will use the broker, so we retry with exponential backoff before panicking. A better solution would be to figure out some way to get the real broker reference threaded to the client, but that is more difficult to figure out right now.